@@ -15,7 +15,7 @@ def _dict_value(v, is_recursive, exclude_none, exclude_none_in_lists):
         return v.to_dict(is_recursive=is_recursive, exclude_none=exclude_none)
     if exclude_none_in_lists and isinstance(v, List):
         return [
-            item.to_dict(exclude_none=exclude_none, is_recursive=is_recursive) if isinstance(item, Prodict) else item
+            item.to_dict(exclude_none=True, is_recursive=is_recursive) if isinstance(item, Prodict) else item
             for item in v]
     return v
 
